Tutorials and FAQs
==================

The following introductory tutorials will help you get started with ``21cmFAST``:

.. toctree::
   :maxdepth: 2

   tutorials/coeval_cubes
   tutorials/lightcones

If you've covered the tutorials and still have questions about "how to do stuff" in
``21cmFAST``, consult the FAQs:

.. toctree::
   :maxdepth: 2

   faqs/installation_faq
   faqs/misc
